Documentation
¶
Index ¶
- type Builder
- func (b *Builder) CreateReporter(mFactory metrics.Factory, logger *zap.Logger) (*Reporter, error)
- func (b *Builder) WithChannel(c *tchannel.Channel) *Builder
- func (b *Builder) WithCollectorServiceName(s string) *Builder
- func (b *Builder) WithDiscoverer(d discovery.Discoverer) *Builder
- func (b *Builder) WithDiscoveryNotifier(n discovery.Notifier) *Builder
- type Reporter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Builder ¶
type Builder struct {
// CollectorHostPorts are host:ports of a static list of Jaeger Collectors.
CollectorHostPorts []string `yaml:"collectorHostPorts"`
// MinPeers is the min number of servers we want the agent to connect to.
// If zero, defaults to min(3, number of peers returned by service discovery)
DiscoveryMinPeers int `yaml:"minPeers"`
// CollectorServiceName is the name that Jaeger Collector's TChannel server
// responds to.
CollectorServiceName string `yaml:"collectorServiceName"`
// contains filtered or unexported fields
}
Builder Struct to hold configurations
func (*Builder) CreateReporter ¶
CreateReporter creates the TChannel-based Reporter
func (*Builder) WithChannel ¶
WithChannel sets tchannel channel
func (*Builder) WithCollectorServiceName ¶
WithCollectorServiceName sets collector service name
func (*Builder) WithDiscoverer ¶
func (b *Builder) WithDiscoverer(d discovery.Discoverer) *Builder
WithDiscoverer sets service discovery
type Reporter ¶
type Reporter struct {
// contains filtered or unexported fields
}
Reporter forwards received spans to central collector tier over TChannel.
func New ¶
func New( collectorServiceName string, channel *tchannel.Channel, peerListMgr *peerlistmgr.PeerListManager, mFactory metrics.Factory, zlogger *zap.Logger, ) *Reporter
New creates new TChannel-based Reporter.
func (*Reporter) EmitZipkinBatch ¶
func (r *Reporter) EmitZipkinBatch(spans []*zipkincore.Span) error
EmitZipkinBatch implements EmitZipkinBatch() of Reporter
Click to show internal directories.
Click to hide internal directories.